@@ -3,7 +3,8 @@
 #' \code{mdirt} fits a variety of item response models with discrete latent variables.
 #' These include, but are not limited to, latent class analysis, multidimensional latent
 #' class models, multidimensional discrete latent class models, DINA/DINO models,
-#' grade of measurement models, and so on.
+#' grade of measurement models, C-RUM, and so on. If response models are not defined explicitly
+#' then customized models can defined using the \code{\link{createItem}} function.
 #'
 #' Posterior classification accuracy for each response pattern may be obtained
 #' via the \code{\link{fscores}} function. The \code{summary()} function will display
@@ -26,6 +27,17 @@
 #' grid of \eqn{\theta} values will allow the estimation of similar models (multidimensional
 #' discrete models, grade of membership, etc.). See the examples below.
 #'
+#' When the \code{item.Q} for is utilized, the above equation can be understood as
+#'
+#' \deqn{P(x = k|\theta_1, \theta_2, a1, a2) = \frac{exp(a1 \theta_1 Q_{j1} + a2 \theta_2 Q_{j2})}{
+#'   \sum_j^K exp(a1 \theta_1 Q_{j1} + a2 \theta_2 Q_{j2})}}
+#'
+#' where by construction \code{Q} is a \eqn{K_i \times A} matrix indicating whether the category should
+#' be modeled according to the latent class structure. For the standard latent class model, the Q-matrix
+#' has as many rows as categories, as many columns as the number of classes/attributes modeled,
+#' and consist of 0's in the first row and 1's elsewhere. This of course can be over-written by passing
+#' an alternative \code{item.Q} definition for each respective item.
+#'
 #' @param data a \code{matrix} or \code{data.frame} that consists of
 #'   numerically ordered data, with missing data coded as \code{NA}
 #' @param model number of mutually exclusive classes to fit, or alternatively a more specific
@@ -40,13 +52,21 @@
 #' @param itemtype a vector indicating the itemtype associated with each item.
 #'   For discrete models this is limited to only 'lca' or items defined using a
 #'   \code{\link{createItem}} definition
+#' @param item.Q a list of item-level Q-matrices indicating how the respective categories should be
+#'   modeled by the underlying attributes. Each matrix must represent a \eqn{K_i \times A} matrix,
+#'   where \eqn{K_i} represents the number of categories for the ith item, and \eqn{A} is the number
+#'   of attributes included in the \code{Theta} matrix; otherwise, a value of\code{NULL} will default
+#'   to a matrix consisting of 1's for each \eqn{K_i \times A} element except for the first row, which
+#'   contains only 0's for proper identification. Incidentally, the first row of each matrix \code{must}
+#'   contain only 0's so that the first category represents the reference category for identification
 #' @param GenRandomPars logical; use random starting values
 #' @param customTheta input passed to \code{technical = list(customTheta = ...)}, but is included
 #'   directly in this function for convenience. This input is most interesting for discrete latent models
-#'   because it allows customized patterns of latent class effects (defines the possible combinations
+#'   because it allows customized patterns of latent classes (i.e., defines the possible combinations
 #'   of the latent attribute profile). The default builds the pattern \code{customTheta = diag(model)},
-#'   which is the typical pattern for the traditional
-#'   latent class analysis whereby classes are completely distinct
+#'   which is the typical pattern for the traditional latent class analysis whereby class
+#'   membership mutually distinct and exhaustive. See \code{\link{thetaComb}} for a quick method
+#'   to generate a matrix with all possible combinations
 #' @param nruns a numeric value indicating how many times the model should be fit to the data
 #'   when using random starting values. If greater than 1, \code{GenRandomPars} is set to true
 #'   by default
@@ -55,9 +75,13 @@
 #' @param covdata a data.frame of data used for latent regression models
 #' @param formula an R formula (or list of formulas) indicating how the latent traits
 #'   can be regressed using external covariates in \code{covdata}. If a named list
-#'   of formulas is supplied (where the names correspond to the latent trait names in \code{model})
+#'   of formulas is supplied (where the names correspond to the latent trait/attribute names in \code{model})
 #'   then specific regression effects can be estimated for each factor. Supplying a single formula
-#'   will estimate the regression parameters for all latent traits by default
+#'   will estimate the regression parameters for all latent variables by default
+#' @param structure an R formula allowing the profile probability patterns (i.e., the structural component of
+#'   the model) to be fitted according to a log-linear model. When \code{NULL}, all profile probabilities
+#'   (except one) will be estimated. Use of this input requires that the \code{customTheta} input is supplied,
+#'   and that the column names in this matrix match the names found within this formula
 #' @param pars used for modifying starting values; see \code{\link{mirt}} for details
 #' @param verbose logical; turn on messages to the R console
 #' @param technical list of lower-level inputs. See \code{\link{mirt}} for details
@@ -69,7 +93,7 @@
 #' Chalmers, R., P. (2012). mirt: A Multidimensional Item Response Theory
 #' Package for the R Environment. \emph{Journal of Statistical Software, 48}(6), 1-29.
 #' \doi{10.18637/jss.v048.i06}
-#' @seealso \code{\link{fscores}}, \code{\link{mirt.model}}, \code{\link{M2}},
+#' @seealso \code{\link{thetaComb}}, \code{\link{fscores}}, \code{\link{mirt.model}}, \code{\link{M2}},
 #'   \code{\link{itemfit}}, \code{\link{boot.mirt}}, \code{\link{mirtCluster}},
 #'   \code{\link{wald}}, \code{\link{coef-method}}, \code{\link{summary-method}},
 #'   \code{\link{anova-method}}, \code{\link{residuals-method}}
@@ -141,8 +165,7 @@
 #'      key = c(1,4,5,2,3,1,2,1,3,1,2,4,2,1,5,3,4,4,1,4,3,3,4,1,3,5,1,3,1,5,4,5))
 #'
 #' # define Theta grid for three latent classes
-#' (Theta <- matrix(c(0,0,0, 1,0,0, 0,1,0, 0,0,1, 1,1,0, 1,0,1, 0,1,1, 1,1,1),
-#'    ncol=3, byrow=TRUE))
+#' (Theta <- thetaComb(0:1, 3))
 #' (mod_discrete <- mdirt(dat, 3, customTheta = Theta))
 #' summary(mod_discrete)
 #'
@@ -172,33 +195,28 @@
 #' dat <- simdata(a, Theta=Theta, itemtype = 'lca')
 #'
 #' # first column is the intercept, 2nd and 3rd are attributes
-#' theta <- matrix(c(1,0,0,
-#'                   1,1,0,
-#'                   1,0,1,
-#'                   1,1,1), 4, 3, byrow=TRUE)
+#' theta <- cbind(1, thetaComb(0:1, 2))
 #' theta <- cbind(theta, theta[,2] * theta[,3]) #DINA interaction of main attributes
 #' model <- mirt.model('Intercept = 1-15
 #'                      A1 = 1-5
 #'                      A2 = 6-10
 #'                      A1A2 = 11-15')
 #'
-#' mod <- mdirt(dat, model, customTheta = theta)
-#' coef(mod)
-#' summary(mod)
-#' M2(mod) # fits well
+#' # last 5 items are DINA (first 10 are unidimensional C-RUMs)
+#' DINA <- mdirt(dat, model, customTheta = theta)
+#' coef(DINA, simplify=TRUE)
+#' summary(DINA)
+#' M2(DINA) # fits well (as it should)
 #'
-#' cfs <- coef(mod, simplify=TRUE)$items[11:15,]
+#' cfs <- coef(DINA, simplify=TRUE)$items[11:15,]
 #' cbind(guess, estguess = plogis(cfs[,1]))
 #' cbind(slip, estslip = 1 - plogis(rowSums(cfs)))
 #'
 #'
 #' ### DINO model example
-#' theta <- matrix(c(1,0,0,
-#'                   1,1,0,
-#'                   1,0,1,
-#'                   1,1,1), 4, 3, byrow=TRUE)
+#' theta <- cbind(1, thetaComb(0:1, 2))
 #' # define theta matrix with negative interaction term
-#' theta <- cbind(theta, -theta[,2] * theta[,3])
+#' (theta <- cbind(theta, -theta[,2] * theta[,3]))
 #'
 #' model <- mirt.model('Intercept = 1-15
 #'                      A1 = 1-5, 11-15
@@ -207,11 +225,24 @@
 #'                      CONSTRAIN = (11,a2,a3,a4), (12,a2,a3,a4), (13,a2,a3,a4),
 #'                                  (14,a2,a3,a4), (15,a2,a3,a4)')
 #'
-#' mod <- mdirt(dat, model, customTheta = theta)
-#' coef(mod, simplify=TRUE)
-#' summary(mod)
-#' M2(mod) #doesn't fit as well, because not the generating model
+#' # last five items are DINOs (first 10 are unidimensional C-RUMs)
+#' DINO <- mdirt(dat, model, customTheta = theta)
+#' coef(DINO, simplify=TRUE)
+#' summary(DINO)
+#' M2(DINO) #doesn't fit as well, because not the generating model
 #'
+#' ## C-RUM (analogous to MIRT model)
+#' theta <- cbind(1, thetaComb(0:1, 2))
+#' model <- mirt.model('Intercept = 1-15
+#'                      A1 = 1-5, 11-15
+#'                      A2 = 6-15')
+#'
+#' CRUM <- mdirt(dat, model, customTheta = theta)
+#' coef(CRUM, simplify=TRUE)
+#' summary(CRUM)
+#'
+#' # good fit, but over-saturated (main effects for items 11-15 can be set to 0)
+#' M2(CRUM)
 #'
 #' #------------------
 #' #multidimensional latent class model
@@ -255,13 +286,15 @@
 #'
 #'
 #' }
-mdirt <- function(data, model, customTheta = NULL, nruns = 1, method = 'EM',
-                  covdata = NULL, formula = NULL, itemtype = 'lca',
+mdirt <- function(data, model, customTheta = NULL, structure = NULL, item.Q = NULL,
+                  nruns = 1, method = 'EM', covdata = NULL, formula = NULL, itemtype = 'lca',
                   optimizer = 'nlminb', return_max = TRUE, group = NULL, GenRandomPars = FALSE,
                   verbose = TRUE, pars = NULL, technical = list(), ...)
 {
     Call <- match.call()
     dots <- list(...)
+    if(!is.null(dots$dentype))
+        stop('mdirt does not support changing the dentype input', call.=FALSE)
     latent.regression <- latentRegression_obj(data=data, covdata=covdata, formula=formula,
                                               dentype = 'discrete', method=method)
     technical$customTheta <- customTheta
@@ -275,9 +308,9 @@ mdirt <- function(data, model, customTheta = NULL, nruns = 1, method = 'EM',
     if((is(model, 'mirt.model') || is.character(model)) && is.null(technical$customTheta))
         stop('customTheta input required when using a mirt.model type input')
     mods <- myLapply(1:nruns, function(x, ...) return(ESTIMATION(...)), method=method,
-                     latent.regression=latent.regression,
+                     latent.regression=latent.regression, structure=structure,
                      data=data, model=model, group=group, itemtype=itemtype, optimizer=optimizer,
-                     technical=technical, calcNull=FALSE, GenRandomPars=GenRandomPars,
+                     technical=technical, calcNull=FALSE, GenRandomPars=GenRandomPars, item.Q=item.Q,
                      dentype = 'discrete', verbose=ifelse(nruns > 1L, FALSE, verbose), pars=pars, ...)
     if(is(mods[[1L]], 'DiscreteClass')){
         for(i in 1:length(mods)) mods[[i]]@Call <- Call
